name_avatar library

A Very Good Project created by Very Good CLI.

Classes

NameAvatar
A StatelessWidget that displays a name Text avatar with a customizable radius, background color, text style, and text color.